local abacus = AceLibrary("Abacus-2.0")
local L = AceLibrary("AceLocale-2.2"):new("Automaton_Repair")
Automaton_Repair = Automaton:NewModule("Repair", "AceEvent-2.0", "AceConsole-2.0", "AceDebug-2.0")
local module = Automaton_Repair

L:RegisterTranslations("enUS", function() return {
	["Repair"] = true,
	["Automatically repair all inventory items when at merchant"] = true,
	["Use Guild Bank Funds"] = true,
	["With this option enabled, Repair will try to repair from guild bank funds before using your personal money."] = true,
	["Repairing all items for %s"] = true,
	["Repairing all items for %s from guild bank funds"] = true,
	["You cannot afford to repair. Go farm you poor newbie."] = true,
} end)

L:RegisterTranslations("esES", function() return {
	["Repair"] = "Reparar",
	["Automatically repair all inventory items when at merchant"] = "Repara autom\195\161ticamente todos tus objetos del inventario cuando est\195\161s en un vendedor",
--	["Use Guild Bank Funds"] = "",
--	["With this option enabled, Repair will try to repair from guild bank funds before using your personal money."] = "",
	["Repairing all items for %s"] = "Reparando todos los objetos por %s",
--	["Repairing all items for %s from guild bank funds"] = "",
	["You cannot afford to repair. Go farm you poor newbie."] = "No tienes suficiente dinero para la reparaci\195\179n",
} end)

L:RegisterTranslations("frFR", function() return {
	["Repair"] = "Réparer",
	["Automatically repair all inventory items when at merchant"] = "Repare automatiquement tous les objets de votres inventaire chez les marchands",
	["Use Guild Bank Funds"] = "Utiliser les fonds de la banque de guilde",
	["With this option enabled, Repair will try to repair from guild bank funds before using your personal money."] = "En activant cette option, les fonds de la banque de guilde seront utilisé en priorité pour effectuer les réparations",
	["Repairing all items for %s"] = "Réparation de tous les objets pour %s",
	["Repairing all items for %s from guild bank funds"] = "Réparation de tous les objets pour %s des fonds de la banque de guilde",
	["You cannot afford to repair. Go farm you poor newbie."] = "Vous ne pouvez pas vous permettre de réparer. Va farmer péon ^^.",
} end)

L:RegisterTranslations("koKR", function() return {
	["Repair"] = "아이템 수리",
	["Automatically repair all inventory items when at merchant"] = "상인에게 모든 아이템을 자동으로 수리합니다.",
--	["Use Guild Bank Funds"] = "",
--	["With this option enabled, Repair will try to repair from guild bank funds before using your personal money."] = "",
	["Repairing all items for %s"] = "모든 아이템 수리: %s",
--	["Repairing all items for %s from guild bank funds"] = "",
	["You cannot afford to repair. Go farm you poor newbie."] = "당신은 아이템 수리를 할 수 없습니다. 돈이 부족합니다.",
} end)

L:RegisterTranslations("zhCN", function() return {
--	["Repair"] = "Repair",
	["Automatically repair all inventory items when at merchant"] = "当打开商人窗口时自动修理全部装备",
--	["Use Guild Bank Funds"] = "Use Guild Bank Funds",
--	["With this option enabled, Repair will try to repair from guild bank funds before using your personal money."] = "",
	["Repairing all items for %s"] = "本次修理花费：%s",
--	["Repairing all items for %s from guild bank funds"] = "",
	["You cannot afford to repair. Go farm you poor newbie."] = "你个穷鬼都修不起你的装备，赶紧去Farm去！",
} end)

L:RegisterTranslations("zhTW", function() return {
	["Repair"] = "自動修裝",
	["Automatically repair all inventory items when at merchant"] = "自動修理裝備",
--	["Use Guild Bank Funds"] = "",
--	["With this option enabled, Repair will try to repair from guild bank funds before using your personal money."] = "",
	["Repairing all items for %s"] = "此次共修理了 : %s",
--	["Repairing all items for %s from guild bank funds"] = "",
	["You cannot afford to repair. Go farm you poor newbie."] = "你身上沒有組購的修裝費用!",
} end)

module.description = L["Automatically repair all inventory items when at merchant"]
module.options = {
	guild = {
		name = L["Use Guild Bank Funds"],
		desc = L["With this option enabled, Repair will try to repair from guild bank funds before using your personal money."],
		type = "toggle",
		get = function() return module.db.profile.guild end,
		set = function(v) module.db.profile.guild = v end,
	}
}

function module:OnInitialize()
	self.db = Automaton:AcquireDBNamespace("Repair")
	Automaton:RegisterDefaults('Repair', 'profile', {
		disabled = true,
		guild = false,
	})
	self:RegisterOptions(self.options)
end

function module:OnEnable()
	self:RegisterEvent("MERCHANT_SHOW")
end

function Automaton_Repair:MERCHANT_SHOW()
	if not CanMerchantRepair() then return end

	local cost = GetRepairAllCost()
	if cost > 0 then
		local money = GetMoney()

		if self.db.guild and IsInGuild() then
			local guildMoney = GetGuildBankWithdrawMoney()
			if guildMoney == -1 then
				guildMoney = GetGuildBankMoney()
			end
			if guildMoney > cost then
				if not self:IsDebugging() then
					RepairAllItems(1)
				end
				self:Print(L["Repairing all items for %s from guild bank funds"], abacus:FormatMoneyFull(cost, true))
				return
			end
		end
		
		if money > cost then
			if not self:IsDebugging() then
				RepairAllItems()
			end
			self:Print(L["Repairing all items for: %s"], abacus:FormatMoneyFull(repairCost, true))
		else
			self:Print(L["You cannot afford to repair. Go farm you poor newbie."])
		end
	end
end
